PageFormatOptions class

Configuration options on how the page is formatted.

Constructors

PageFormatOptions({PageFormat pageFormat = PageFormat.a4, double? width, double? height, double marginTop = 0.0, double marginBottom = 0.0, double marginLeft = 0.0, double marginRight = 0.0, double? marginAll, bool clip = false})
const
PageFormatOptions.a3({bool clip = false})
const
PageFormatOptions.a4({bool clip = false})
const
PageFormatOptions.a5({bool clip = false})
const
PageFormatOptions.a6({bool clip = false})
const
PageFormatOptions.custom({required double? width, double? height, double marginTop = 0.0, double marginBottom = 0.0, double marginLeft = 0.0, double marginRight = 0.0, double? marginAll, bool clip = false})
PageFormatOptions.legal({bool clip = false})
const
PageFormatOptions.letter({bool clip = false})
const
PageFormatOptions.roll57({bool clip = false})
const
PageFormatOptions.roll80({bool clip = false})
const

Properties

clip → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
marginAll → double?
final
marginBottom → double
final
marginLeft → double
final
marginRight → double
final
marginTop → double
final
pageFormat → PageFormat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
final

Methods

getAvailableSize() → Size
Returns the available Size of the page.
getPageFormat() → PdfPageFormat
Returns the PdfPageFormat.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited