TextFieldOptions class

Configuration options on how TextFields are exported.

Constructors

TextFieldOptions({Map<Key, TextStyle>? styleMap, bool interactive = true, bool ignoreDecoration = false})
const
TextFieldOptions.individual({Map<Key, TextStyle>? styleMap, bool interactive = true, bool ignoreDecoration = false})
const
TextFieldOptions.none()
const
TextFieldOptions.uniform({TextStyle textStyle = const TextStyle(), bool interactive = true, bool ignoreDecoration = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreDecoration → bool
If true, the text fields InputDecoration will be ignored.
final
interactive → bool
If false, the text field will be rendered as a static text.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleMap → Map<Key, TextStyle>?
A map of Key to TextStyle to apply to the text field.
final

Methods

getTextStyle(Key? key) → TextStyle?
Returns the TextStyle for the given key. If key is null, the standard key will be used. If key still is not found, null is returned.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited